@@ -47,8 +47,11 @@ namespace sharp {
     bool is_file() const;
     std::string local_path() const;
     std::string get_host() const;
+    std::string get_absolute_uri() const;
     static std::string escape_uri_string(const std::string &);
   private:
+    bool _is_scheme(const std::string & scheme) const;
+
     std::string m_uri;
   };
 
